package com.usky.dxtop.controller.web;


import com.usky.dxtop.common.core.domain.AjaxResult;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.emun.OrderStatus;
import com.usky.dxtop.service.vo.OrderRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;

/**
 * <p>
 * 订单表 前端控制器
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/order")
public class OrderController extends BaseController {

    @Autowired
    private OrderService orderService;

    /**
     * 添加订单(现金支付)
     * @param order
     * @return
     */
    @PostMapping
    public AjaxResult add(@RequestBody Order order){
        return toAjax(orderService.add(order));
    }

    /**
     * 修改订单状态
     * @param order
     * @return
     */
    @PutMapping
    public AjaxResult update(@RequestBody Order order){
        order.setOrderFlag(OrderStatus.SUCCESS.getCode());
        return toAjax(orderService.updateById(order));
    }

    /**
     * 删除订单
     * @param orderNumber
     * @return
     */
    @DeleteMapping("/{orderNumber}")
    public AjaxResult remove(@PathVariable("orderNumber") String orderNumber){
        return toAjax(orderService.remove(orderNumber));
    }

    /**
     * 分页
     * @param orderRequest
     * @return
     */
    @PostMapping("/list")
    public AjaxResult list(@RequestBody OrderRequest orderRequest){
        return AjaxResult.success(orderService.list(orderRequest));
    }

    /**
     * 扫码支付api
     * @param order
     * @return
     */
    @PostMapping("/topScanPayApi")
    public AjaxResult getTopScanPayApi(@RequestBody Order order){
        return AjaxResult.success(orderService.getTopScanPayApi(order));
    }

    /**
     * 生成扫码支付二维码
     * @param order
     * @return
     */
    @PostMapping("/topScanPayQr")
    public AjaxResult getTopScanPayQr(@RequestBody Order order){
        return AjaxResult.success(orderService.getTopScanPayQr(order));
    }

    /**
     * 查看订单详情api
     * @param orderNumber
     * @return
     */
    @GetMapping("/{orderNumber}")
    public AjaxResult callTopFindOrderInfoApi(@PathVariable("orderNumber") String orderNumber){
        return AjaxResult.success(orderService.callTopFindOrderInfoApi(orderNumber));
    }

    @PostMapping("/exportDetail")
    public void exportDetail(@RequestBody OrderRequest orderRequest, HttpServletResponse response){
        orderService.exportDetail(orderRequest,response);
    }

    /**
     * 订单报表
     * @param current
     * @param size
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    @GetMapping("/orderReportList")
    public AjaxResult orderReportList(@RequestParam Integer current,
                                      @RequestParam Integer size,
                                      @RequestParam(required = false) Date startTime,
                                      @RequestParam(required = false) Date endTime,
                                      @RequestParam Integer type){
        return AjaxResult.success(orderService.orderReportList(current,size,startTime,endTime,type));
    }

    /**
     * 报表导出
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    @GetMapping("/reportExport")
    public void reportExport(@RequestParam(required = false) Date startTime,
                                   @RequestParam(required = false) Date endTime,
                                   @RequestParam Integer type,
                                     HttpServletResponse response){
        orderService.reportExport(startTime,endTime,type,response);
    }

    @PostMapping("callUnifiedPay")
    public AjaxResult callUnifiedPay(@RequestBody Order order){
        return AjaxResult.success(orderService.callUnifiedPay(order));
    }
}

